use strict;
use warnings;
package Task::BeLike::Andrefs;
{
  $Task::BeLike::Andrefs::VERSION = '0.05_15';
}

# ABSTRACT: For all the AndreFS wanna-bes

1;

__END__

=pod

=head1 NAME

Task::BeLike::Andrefs - For all the AndreFS wanna-bes

=head1 VERSION

version 0.05_15

=head1 AUTHOR

Andre Santos <andrefs@cpan.org>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2011 by Andre Santos.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut
